@@ -1,19 +1,16 @@
 ### R code from vignette source 'VAM_pbmc_small.Rnw'
 
 ###################################################
-### code chunk number 1: VAM_pbmc_small.Rnw:16-23
+### code chunk number 1: VAM_pbmc_small.Rnw:16-20
 ###################################################
 library(VAM)
 if (!requireNamespace("Seurat", quietly=TRUE)) {
    stop("Seurat package not available!")
 }
-if (!requireNamespace("SeuratObject", quietly=TRUE)) {
-   stop("SeuratObject package not available!")
-}
 
 
 ###################################################
-### code chunk number 2: VAM_pbmc_small.Rnw:30-34
+### code chunk number 2: VAM_pbmc_small.Rnw:27-31
 ###################################################
 SeuratObject::pbmc_small
 gene.names = rownames(SeuratObject::pbmc_small)
@@ -22,7 +19,7 @@ Seurat::VariableFeatures(SeuratObject::pbmc_small)[1:5]
 
 
 ###################################################
-### code chunk number 3: VAM_pbmc_small.Rnw:41-53
+### code chunk number 3: VAM_pbmc_small.Rnw:38-50
 ###################################################
 gene.set.name = "Test"
 gene.ids = c("PPBP", "IGLL5", "VDAC3", "CD1C", "AKR1C3")
@@ -39,7 +36,7 @@ gene.indices = gene.set.collection[[1]]
 
 
 ###################################################
-### code chunk number 4: VAM_pbmc_small.Rnw:60-63
+### code chunk number 4: VAM_pbmc_small.Rnw:57-60
 ###################################################
 pbmc.vam = vamForSeurat(seurat.data=SeuratObject::pbmc_small,
     gene.set.collection=gene.set.collection,
@@ -47,14 +44,14 @@ pbmc.vam = vamForSeurat(seurat.data=SeuratObject::pbmc_small,
 
 
 ###################################################
-### code chunk number 5: VAM_pbmc_small.Rnw:68-70
+### code chunk number 5: VAM_pbmc_small.Rnw:65-67
 ###################################################
 pbmc.vam@assays$VAMdist[1,1:10]
 pbmc.vam@assays$VAMcdf[1,1:10]
 
 
 ###################################################
-### code chunk number 6: VAM_pbmc_small.Rnw:77-79
+### code chunk number 6: VAM_pbmc_small.Rnw:74-76
 ###################################################
 Seurat::DefaultAssay(object = pbmc.vam) = "VAMcdf"
 Seurat::FeaturePlot(pbmc.vam, reduction="tsne", features=gene.set.name)
